Class: Connector
- Inherits:
-
Object
- Object
- Connector
- Defined in:
- lib/wingify/packages/storage/connector.rb
Overview
Copyright 2024-2026 Wingify Software Pvt. Ltd.
Licensed under the Apache License, Version 2.0 (the “License”); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an “AS IS” BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Instance Method Summary collapse
-
#get(_key) ⇒ Object
Define an abstract method for getting data.
-
#set(_key, _data) ⇒ Object
Define an abstract method for setting data.
Instance Method Details
#get(_key) ⇒ Object
Define an abstract method for getting data
22 23 24 |
# File 'lib/wingify/packages/storage/connector.rb', line 22 def get(_key) raise NotImplementedError, "#{self.class} must implement the `get` method" end |
#set(_key, _data) ⇒ Object
Define an abstract method for setting data
17 18 19 |
# File 'lib/wingify/packages/storage/connector.rb', line 17 def set(_key, _data) raise NotImplementedError, "#{self.class} must implement the `set` method" end |