Class: SetAttributeApi
- Inherits:
-
Object
- Object
- SetAttributeApi
- Defined in:
- lib/wingify/api/set_attribute.rb
Instance Method Summary collapse
-
#set_attribute(attributes, context) ⇒ Object
Sets multiple attributes for a user in a single network call.
Instance Method Details
#set_attribute(attributes, context) ⇒ Object
Sets multiple attributes for a user in a single network call.
24 25 26 |
# File 'lib/wingify/api/set_attribute.rb', line 24 def set_attribute(attributes, context) create_impression_for_attributes(attributes, context) end |