Class: VWOOptionsModel

Inherits:
Object
  • Object
show all
Defined in:
lib/wingify/models/vwo_options_model.rb

Overview

Copyright 2024-2026 Wingify Software Pvt. Ltd.

Licensed under the Apache License, Version 2.0 (the “License”); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an “AS IS” BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options = {}) ⇒ VWOOptionsModel

Returns a new instance of VWOOptionsModel.



21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/wingify/models/vwo_options_model.rb', line 21

def initialize(options = {})
  @account_id = options[:account_id]
  @sdk_key = options[:sdk_key]
  @is_development_mode = options[:is_development_mode]
  @storage = options[:storage]
  @gateway_service = options[:gateway_service]
  @poll_interval = options[:poll_interval]
  @logger = options[:logger]
  @segmentation = options[:segmentation]
  @integrations = options[:integrations]
  @network = options[:network]
  @should_wait_for_tracking_calls = options[:should_wait_for_tracking_calls]
  @settings = options[:settings]
  @vwo_builder = options[:vwo_builder]
  @is_usage_stats_disabled = options[:is_usage_stats_disabled]
  @_vwo_meta = options[:_vwo_meta]
  @retry_config = options[:retry_config]
  @proxy_url = options[:proxy_url]
end

Instance Attribute Details

#_vwo_metaObject

Returns the value of attribute _vwo_meta.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def _vwo_meta
  @_vwo_meta
end

#account_idObject

Returns the value of attribute account_id.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def 
  @account_id
end

#gateway_serviceObject

Returns the value of attribute gateway_service.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def gateway_service
  @gateway_service
end

#integrationsObject

Returns the value of attribute integrations.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def integrations
  @integrations
end

#is_development_modeObject

Returns the value of attribute is_development_mode.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def is_development_mode
  @is_development_mode
end

#is_usage_stats_disabledObject

Returns the value of attribute is_usage_stats_disabled.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def is_usage_stats_disabled
  @is_usage_stats_disabled
end

#loggerObject

Returns the value of attribute logger.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def logger
  @logger
end

#networkObject

Returns the value of attribute network.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def network
  @network
end

#poll_intervalObject

Returns the value of attribute poll_interval.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def poll_interval
  @poll_interval
end

#proxy_urlObject

Returns the value of attribute proxy_url.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def proxy_url
  @proxy_url
end

#retry_configObject

Returns the value of attribute retry_config.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def retry_config
  @retry_config
end

#sdk_keyObject

Returns the value of attribute sdk_key.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def sdk_key
  @sdk_key
end

#segmentationObject

Returns the value of attribute segmentation.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def segmentation
  @segmentation
end

#settingsObject

Returns the value of attribute settings.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def settings
  @settings
end

#should_wait_for_tracking_callsObject

Returns the value of attribute should_wait_for_tracking_calls.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def should_wait_for_tracking_calls
  @should_wait_for_tracking_calls
end

#storageObject

Returns the value of attribute storage.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def storage
  @storage
end

#vwo_builderObject

Returns the value of attribute vwo_builder.



16
17
18
# File 'lib/wingify/models/vwo_options_model.rb', line 16

def vwo_builder
  @vwo_builder
end

Instance Method Details

#get_account_idObject



62
63
64
# File 'lib/wingify/models/vwo_options_model.rb', line 62

def 
  @account_id
end

#get_gateway_serviceObject



78
79
80
# File 'lib/wingify/models/vwo_options_model.rb', line 78

def get_gateway_service
  @gateway_service
end

#get_integrationsObject



94
95
96
# File 'lib/wingify/models/vwo_options_model.rb', line 94

def get_integrations
  @integrations
end

#get_is_development_modeObject



70
71
72
# File 'lib/wingify/models/vwo_options_model.rb', line 70

def get_is_development_mode
  @is_development_mode
end

#get_is_usage_stats_disabledObject



114
115
116
# File 'lib/wingify/models/vwo_options_model.rb', line 114

def get_is_usage_stats_disabled
  @is_usage_stats_disabled
end

#get_loggerObject



86
87
88
# File 'lib/wingify/models/vwo_options_model.rb', line 86

def get_logger
  @logger
end

#get_networkObject



98
99
100
# File 'lib/wingify/models/vwo_options_model.rb', line 98

def get_network
  @network
end

#get_poll_intervalObject



82
83
84
# File 'lib/wingify/models/vwo_options_model.rb', line 82

def get_poll_interval
  @poll_interval
end

#get_proxy_urlObject



126
127
128
# File 'lib/wingify/models/vwo_options_model.rb', line 126

def get_proxy_url
  @proxy_url
end

#get_retry_configObject



122
123
124
# File 'lib/wingify/models/vwo_options_model.rb', line 122

def get_retry_config
  @retry_config
end

#get_sdk_keyObject



66
67
68
# File 'lib/wingify/models/vwo_options_model.rb', line 66

def get_sdk_key
  @sdk_key
end

#get_segmentationObject



90
91
92
# File 'lib/wingify/models/vwo_options_model.rb', line 90

def get_segmentation
  @segmentation
end

#get_settingsObject



106
107
108
# File 'lib/wingify/models/vwo_options_model.rb', line 106

def get_settings
  @settings
end

#get_should_wait_for_tracking_callsObject



102
103
104
# File 'lib/wingify/models/vwo_options_model.rb', line 102

def get_should_wait_for_tracking_calls
  @should_wait_for_tracking_calls
end

#get_storageObject



74
75
76
# File 'lib/wingify/models/vwo_options_model.rb', line 74

def get_storage
  @storage
end

#get_vwo_builderObject



110
111
112
# File 'lib/wingify/models/vwo_options_model.rb', line 110

def get_vwo_builder
  @vwo_builder
end

#get_vwo_metaObject



118
119
120
# File 'lib/wingify/models/vwo_options_model.rb', line 118

def get_vwo_meta
  @_vwo_meta
end

#model_from_dictionary(options) ⇒ Object

Creates a model instance from a hash (dictionary)



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/wingify/models/vwo_options_model.rb', line 42

def model_from_dictionary(options)
  @account_id = options[:account_id]
  @sdk_key = options[:sdk_key]
  @vwo_builder = options[:vwo_builder]

  @should_wait_for_tracking_calls = options[:should_wait_for_tracking_calls] if options.key?(:should_wait_for_tracking_calls)
  @is_development_mode = options[:is_development_mode] if options.key?(:is_development_mode)
  @storage = options[:storage] if options.key?(:storage)
  @gateway_service = options[:gateway_service] if options.key?(:gateway_service)
  @poll_interval = options[:poll_interval] if options.key?(:poll_interval)
  @logger = options[:logger] if options.key?(:logger)
  @segmentation = options[:segmentation] if options.key?(:segmentation)
  @integrations = options[:integrations] if options.key?(:integrations)
  @network = options[:network] if options.key?(:network)
  @settings = options[:settings] if options.key?(:settings)
  @retry_config = options[:retry_config] if options.key?(:retry_config)
  @proxy_url = options[:proxy_url] if options.key?(:proxy_url)
  self
end